@@ -2,23 +2,22 @@ import os
 import io
 import sys
 import csv
-import math
 import glob
+import logging
 import numpy as np
 from dotenv import load_dotenv
 import django
 from django.db import models
 from datetime import datetime
+import matplotlib.image as mpimg
 import matplotlib.pyplot as plt
-from matplotlib.patches import Ellipse
-import astropy.units as u
 from astropy.table import Table
 from astropy.io.votable import from_table, writeto
 from astropy.io.votable.tree import Param
 from astropy.io import fits
-from astropy.wcs import WCS
-from astropy.visualization import PercentileInterval
-from astroquery.skyview import SkyView
+
+
+logging.basicConfig(level=logging.INFO)
 
 
 Run, Instance, Detection, Product, Source = None, None, None, None, None
@@ -227,16 +226,6 @@ def get_catalog(tag):
     return table
 
 
-def save_catalog(tag, *args, **kwargs):
-    """Write catalog of tagged sources. Remove object columns for write to file.
-
-    """
-    table = get_catalog(tag)
-    table['comments'] = [''.join(comment) for comment in table['comments']]
-    table['tags'] = [''.join(t) for t in table['tags']]
-    table.write(*args, **kwargs)
-
-
 def save_products_for_source(tag, source_name, *args, **kwargs):
     """Save source finding output products for a given source name.
 
@@ -341,126 +330,26 @@ def get_spectrum(product):
         return np.loadtxt(buf, dtype="float", comments="#", unpack=True)
 
 
-# Retrieve DSS image from Skyview
-def retrieve_dss_image(longitude, latitude, width, height):
-    hdulist = SkyView.get_images(
-        position="{}, {}".format(longitude, latitude),
-        survey=["DSS"],
-        coordinates="J2000",
-        projection="Tan",
-        width=width*u.deg,
-        height=height*u.deg,
-        cache=None
-    )
-    return hdulist[0][0]
-
-
 # Create overview plot
-def overview_plot(id):
-    interval = PercentileInterval(95.0)
-    plt.rcParams["figure.figsize"] = (16, 12)
-    fig = plt.figure()
-
+def overview_plot(id, size=(8, 6)):
     # Retrieve products from database
-    products = Product.objects.get(detection=id)
+    detection = Detection.objects.get(id=id)
+    products = Product.objects.get(detection=detection)
+    plot = products.plot
+    if plot is None:
+        logging.error(f'No summary plot for detection {detection.name}')
+        return None
 
-    # Open moment 0 image
-    mom0, header = get_image(products.mom0)
-    mom1, header = get_image(products.mom1)
-    spectrum = get_spectrum(products.spec)
-    wcs = WCS(header)
-
-    # Extract coordinate information
-    nx = header["NAXIS1"]
-    ny = header["NAXIS2"]
-    lon, lat = wcs.all_pix2world(nx / 2, ny / 2, 0)
-    tmp1, tmp3 = wcs.all_pix2world(0, ny / 2, 0)
-    tmp2, tmp4 = wcs.all_pix2world(nx, ny / 2, 0)
-    width = np.rad2deg(
-        math.acos(
-            math.sin(np.deg2rad(tmp3)) * math.sin(np.deg2rad(tmp4)) +
-            math.cos(np.deg2rad(tmp3)) * math.cos(np.deg2rad(tmp4)) * math.cos(np.deg2rad(tmp1 - tmp2))
-        )
-    )
-    tmp1, tmp3 = wcs.all_pix2world(nx / 2, 0, 0)
-    tmp2, tmp4 = wcs.all_pix2world(nx / 2, ny, 0)
-    height = np.rad2deg(
-        math.acos(
-            math.sin(np.deg2rad(tmp3)) * math.sin(np.deg2rad(tmp4)) +
-            math.cos(np.deg2rad(tmp3)) * math.cos(np.deg2rad(tmp4)) * math.cos(np.deg2rad(tmp1 - tmp2))
-        )
-    )
-
-    # Plot DSS image with HI contours
-    try:
-        hdu_opt = retrieve_dss_image(lon, lat, width, height)
-        wcs_opt = WCS(hdu_opt.header)
-
-        bmin, bmax = interval.get_limits(hdu_opt.data)
-        ax = plt.subplot(2, 2, 2, projection=wcs_opt)
-        ax.imshow(hdu_opt.data, origin="lower")
-        ax.contour(
-            mom0,
-            transform=ax.get_transform(wcs),
-            levels=np.logspace(2.0, 5.0, 10),
-            colors="lightgrey",
-            alpha=1.0
-        )
-        ax.grid(color="grey", ls="solid")
-        ax.set_xlabel("Right ascension (J2000)")
-        ax.set_ylabel("Declination (J2000)")
-        ax.tick_params(axis="x", which="both", left=False, right=False)
-        ax.tick_params(axis="y", which="both", top=False, bottom=False)
-        ax.set_title("DSS + Moment 0")
-        ax.set_aspect(np.abs(wcs_opt.wcs.cdelt[1] / wcs_opt.wcs.cdelt[0]))
-    except Exception:
-        sys.stderr.write("Failed to retrieve DSS image.\n")
-        pass
-
-    # Plot moment 0
-    ax2 = plt.subplot(2, 2, 1, projection=wcs)
-    ax2.imshow(mom0, origin="lower")
-    ax2.grid(color="grey", ls="solid")
-    ax2.set_xlabel("Right ascension (J2000)")
-    ax2.set_ylabel("Declination (J2000)")
-    ax2.tick_params(axis="x", which="both", left=False, right=False)
-    ax2.tick_params(axis="y", which="both", top=False, bottom=False)
-    ax2.set_title("Moment 0")
-
-    # Add beam size
-    ax2.add_patch(Ellipse((5, 5), 5, 5, 0, edgecolor="grey", facecolor="grey"))
-
-    # Plot moment 1
-    bmin, bmax = interval.get_limits(mom1)
-    ax3 = plt.subplot(2, 2, 3, projection=wcs)
-    ax3.imshow(mom1, origin="lower", vmin=bmin, vmax=bmax, cmap=plt.get_cmap("gist_rainbow"))
-    ax3.grid(color="grey", ls="solid")
-    ax3.set_xlabel("Right ascension (J2000)")
-    ax3.set_ylabel("Declination (J2000)")
-    ax3.tick_params(axis="x", which="both", left=False, right=False)
-    ax3.tick_params(axis="y", which="both", top=False, bottom=False)
-    ax3.set_title("Moment 1")
-
-    # Plot spectrum
-    xaxis = spectrum[1] / 1e+6
-    data = 1000.0 * np.nan_to_num(spectrum[2])
-    xmin = np.nanmin(xaxis)
-    xmax = np.nanmax(xaxis)
-    ymin = np.nanmin(data)
-    ymax = np.nanmax(data)
-    ymin -= 0.1 * (ymax - ymin)
-    ymax += 0.1 * (ymax - ymin)
-    ax4 = plt.subplot(2, 2, 4)
-    ax4.step(xaxis, data, where="mid", color="royalblue")
-    ax4.set_xlabel("Frequency (MHz)")
-    ax4.set_ylabel("Flux density (mJy)")
-    ax4.set_title("Spectrum")
-    ax4.grid(True)
-    ax4.set_xlim([xmin, xmax])
-    ax4.set_ylim([ymin, ymax])
-
-    fig.canvas.draw()
+    fig, ax = plt.subplots(nrows=1, ncols=1)
+    fig.set_size_inches(*size)
+    img = mpimg.imread(io.BytesIO(plot))
+    plt.imshow(img)
+    plt.axis('off')
     plt.tight_layout()
+    ax = plt.gca()
+    ax.set_frame_on(False)
+    ax.get_xaxis().set_visible(False)
+    ax.get_yaxis().set_visible(False)
 
     return plt
 
